==> AGXUnreal-1.17.0_UE-5.4_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/LinearRange.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/RangeInteraction1DOF.h>
#include <openplx/Physics/Signals/Force1DOutputTrait.h>
#include <openplx/Physics/Signals/Position1DOutputTrait.h>
#include <openplx/Physics/Signals/Force1DOutput.h>
#include <openplx/Physics/Signals/Position1DOutput.h>
/* Generated code for model LinearRange */
namespace openplx::Physics3D::Interactions {
    class LinearRange : public openplx::Physics3D::Interactions::RangeInteraction1DOF, public openplx::Physics::Signals::Force1DOutputTrait, public openplx::Physics::Signals::Position1DOutputTrait {
        protected:
            std::shared_ptr<openplx::Physics::Signals::Force1DOutput> m_force_output;
            std::shared_ptr<openplx::Physics::Signals::Position1DOutput> m_position_output;

        public:
            LinearRange();
            std::shared_ptr<openplx::Physics::Signals::Force1DOutput> force_output() const;
            std::shared_ptr<openplx::Physics::Signals::Position1DOutput> position_output() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.5_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/LinearRange.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/RangeInteraction1DOF.h>
#include <openplx/Physics/Signals/Force1DOutputTrait.h>
#include <openplx/Physics/Signals/Force1DOutput.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model LinearRange */
namespace openplx::Physics3D::Interactions {
    class OPENPLX_Physics3D_BUNDLE_EXPORT LinearRange : public openplx::Physics3D::Interactions::RangeInteraction1DOF, public openplx::Physics::Signals::Force1DOutputTrait {
        protected:
            std::shared_ptr<openplx::Physics::Signals::Force1DOutput> m_force_output;

        public:
            LinearRange();
            virtual ~LinearRange();
            std::shared_ptr<openplx::Physics::Signals::Force1DOutput> force_output() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
